import { Command } from '@prisma/cli';
import { Result } from 'arg';
import { Config } from 'prisma-cli-engine';
import { DatabaseType, ISDL } from 'prisma-datamodel';
import { Environment, Output } from 'prisma-yml';
import { PrismaDefinitionClass } from './prisma-config/PrismaDefinition';
import { ConnectorData } from './introspect/util';
import { DatabaseCredentials, IntrospectionResult } from './types';
declare type Args = {
    '--interactive': BooleanConstructor;
    '-i': '--interactive';
    '--env-file': StringConstructor;
    '-e': '--env-file';
    '--project': StringConstructor;
    '-p': '--project';
    /**
     * Postgres Params
     */
    '--pg-host': StringConstructor;
    '--pg-port': StringConstructor;
    '--pg-user': StringConstructor;
    '--pg-password': StringConstructor;
    '--pg-db': StringConstructor;
    '--pg-ssl': BooleanConstructor;
    '--pg-schema': StringConstructor;
    /**
     * MySQL Params
     */
    '--mysql-host': StringConstructor;
    '--mysql-port': StringConstructor;
    '--mysql-user': StringConstructor;
    '--mysql-password': StringConstructor;
    '--mysql-db': StringConstructor;
    /**
     * Mongo Params
     */
    '--mongo-uri': StringConstructor;
    '--mongo-db': StringConstructor;
    '--sdl': BooleanConstructor;
    '--help': BooleanConstructor;
};
export declare class Introspect implements Command {
    protected definition: PrismaDefinitionClass;
    protected out: Output;
    protected config: Config;
    protected env: Environment;
    static new(): Introspect;
    private constructor();
    parse(argv: string[]): Promise<any>;
    getExistingDatamodel(databaseType: DatabaseType): ISDL | null;
    introspect({ connector, databaseType, databaseName, }: ConnectorData): Promise<IntrospectionResult>;
    writeDatamodel(renderedSdl: string): string;
    getConnectorWithDatabase(args: Result<Args>, sdl: boolean | undefined): Promise<IntrospectionResult>;
    getCredentialsByFlags(args: Result<Args>): DatabaseCredentials | null;
    handleMissingArgs(requiredArgs: string[], providedArgs: string[], prefix: string): void;
    /**
     * Introspect the database
     */
    introspectWithSpinner(connectorData: ConnectorData, sdl: boolean | undefined): Promise<IntrospectionResult>;
    help(): void;
}
export {};
