import { DatabaseType } from 'prisma-datamodel';
import { IConnector } from '../../common/connector';
import { DatabaseCredentials } from '../types';
export interface ConnectorAndDisconnect {
    /**
     * The introspection connector instance
     */
    connector: IConnector;
    /**
     * Callback to let the client disconnect
     */
    disconnect: () => Promise<void>;
}
/**
 * This data is needed to perform the introspection
 */
export interface ConnectorData extends ConnectorAndDisconnect {
    /**
     * The concrete database type used by the Connector that is included in this object
     */
    databaseType: DatabaseType;
    /**
     * The database name either directly provided by the user or chosen in the select schema dialog
     */
    databaseName: string;
}
/**
 * As we use a separate function to guarantee for the databaseName, it's optional ehre
 */
export interface IntermediateConnectorData extends ConnectorAndDisconnect {
    databaseType: DatabaseType;
    databaseName?: string;
    interactive: boolean;
}
export declare function getConnectedConnectorFromCredentials(credentials: DatabaseCredentials): Promise<ConnectorAndDisconnect>;
export declare function getDatabaseSchemas(connector: IConnector): Promise<string[]>;
export declare function assertSchemaExists(databaseName: string, databaseType: DatabaseType, schemas: string[]): void;
export declare function sanitizeMongoUri(mongoUri: string): string;
export declare function populateMongoDatabase({ uri, database, }: {
    uri: string;
    database?: string;
}): {
    uri: string;
    database: string;
};
export declare function prettyTime(time: number): string;
